/*
Signal Lite is intended to be a more lightweight, easier to use version of my Signal library. Signal Lite
provides the ability to generate the two most "useful" types of noise: Ken Perlin's simplex noise, and
fractal brownian motion (also known as a plasma fractal or fractally combined simplex noise).

Signal Lite, like Signal, can offload computation of noise to a DLL. To use the DLL, copy SignalLite.dll to
your project's root directory.

To begin generating noise, create a noise object as follows:
	var/Noise/noise = new

Note that if you do not want to use the DLL, you need to supply FALSE as the first argument in new. Example:
	var/Noise/noise = new(FALSE)

Or if you have the .DLL in a different location, you can specify that in the second argument in new. Example:
	var/Noise/noise = new(TRUE, "path/to/SignalLite.dll")

After your object has been created, you can get noise with these four procs:
	noise2(x, y) - calculate Perlin's simplex noise in 2D
	noise3(x, y, z) - calculate Perlin's simplex noise in 3D
	fbm2(x, y) - fractal brownian motion in 2D
	fbm3(x, y, z) - fractal brownian motion in 3D

	Example:
		var/Noise/noise = new
		world << noise.noise2(0.5, 0.5) // returns -0.307157

These noise procs return a value from -1 to 1. You will need to use a function to scale this to a range that
is more useful to you. All Noise objects also have a scale(n, low, high) proc. This proc can take your noise value from -1
to 1 and scale it to a specified range. Example:
	var
		Noise/noise = new
		n = noise.noise2(0.5, 0.5) // -0.307157
		world << noise.scale(n, 0, 255) // returns 88.3375

The Noise object also has the following procs:
	enableDLL() - make the Noise object use the DLL
	disableDLL() - stop the Noise object from using the DLL

	setSeed(seed) - set the seed
	randSeed() - set a random seed from -65535 to 65535
	setOctaves(octaves) - set the number of octaves for fractal noise
	setGain(gain) - set the gain for fractal noise
	setOffset(offset) - set the offset for fractal noise
	setFrequency(frequency) - set the frequency for fractal noise
	setLacunarity(lacunarity) - set the lacunarity for fractal noise

	getSeed() - get the seed
	getOctaves() - get the number of octaves
	getGain() - get the gain
	getOffset() - get the offset
	getFrequency() - get the frequency
	getLacunarity() - get the lacunarity

You don't have to concern yourself with the properties like octaves, gain, offset, frequency, and lacunarity
if you don't understand them. The default values will provide good results.

You can create as many Noise objects as you want. This is useful if you need more than one generator seeded
with different values. The seed of an object will change the noise you get from the noise procs. So, two
/Noise objects with two different seeds will produce different values for the same inputs to noise2, noise3,
fbm2, and fbm3.
*/